
#line 3 "lex.swf5.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE swf5restart(swf5in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int swf5leng;

extern FILE *swf5in, *swf5out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf5text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up swf5text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via swf5restart()), so that the user can continue scanning by
	 * just pointing swf5in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when swf5text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int swf5leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow swf5wrap()'s to do buffer switches
 * instead of setting up a fresh swf5in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void swf5restart (FILE *input_file  );
void swf5_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE swf5_create_buffer (FILE *file,int size  );
void swf5_delete_buffer (YY_BUFFER_STATE b  );
void swf5_flush_buffer (YY_BUFFER_STATE b  );
void swf5push_buffer_state (YY_BUFFER_STATE new_buffer  );
void swf5pop_buffer_state (void );

static void swf5ensure_buffer_stack (void );
static void swf5_load_buffer_state (void );
static void swf5_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER swf5_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE swf5_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE swf5_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE swf5_scan_bytes (yyconst char *bytes,int len  );

void *swf5alloc (yy_size_t  );
void *swf5realloc (void *,yy_size_t  );
void swf5free (void *  );

#define yy_new_buffer swf5_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        swf5ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf5_create_buffer(swf5in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        swf5ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf5_create_buffer(swf5in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *swf5in = (FILE *) 0, *swf5out = (FILE *) 0;

typedef int yy_state_type;

extern int swf5lineno;

int swf5lineno = 1;

extern char *swf5text;
#define yytext_ptr swf5text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up swf5text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	swf5leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 181
#define YY_END_OF_BUFFER 182
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[746] =
    {   0,
        5,    5,    5,    5,    5,    5,  182,  180,  134,  179,
      180,  167,  180,  127,  166,  161,  180,  168,  169,  164,
      159,  174,  160,  175,  165,    3,    3,  177,  157,  155,
      158,  156,  176,  127,  170,  171,  163,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  172,  162,  173,  178,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  167,  158,  127,  127,
      127,  179,  140,    0,  130,  128,    0,  127,  141,  147,
        0,  131,  129,    0,  143,  135,  145,  136,  146,  132,

      133,  144,    4,    2,    3,    0,    0,  149,  137,  139,
      138,  150,    0,    5,  127,  127,  127,  127,  127,  127,
       21,  127,  127,  127,  127,  127,  127,  127,  127,   19,
       18,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  148,  142,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,   18,  127,  127,  127,  127,
      127,  127,  127,  127,   67,  127,  127,    0,  127,  127,
      127,  127,  127,  127,  127,  127,  140,  139,  127,  127,
      127,  127,    4,    0,    5,    1,  152,  153,  151,   28,

      127,  127,  127,   40,  127,  127,  127,  127,  127,  127,
      127,   17,  127,  127,  127,  127,   38,  127,  127,   23,
      127,  127,   39,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,   22,  127,
      127,   70,   66,  127,  127,   77,  127,   59,  116,  127,
      127,  127,  115,   76,  127,  127,  127,  127,  127,  127,
      127,  127,  127,   23,   95,  127,   61,  127,  127,  126,
      127,  127,  127,  127,  127,  127,  127,  127,  127,   22,
       68,  125,  124,  127,  127,  127,  120,    0,    4,  154,
      127,  127,   15,  127,  127,  127,  127,  127,   13,   29,

      127,  127,  127,  127,  127,  127,  127,  127,  127,    8,
       45,  127,  127,  127,  127,  127,   46,  127,  127,  127,
      127,  127,    6,  127,  127,  127,   27,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  114,   62,  127,  127,  127,  127,  127,  127,  127,
       46,  127,  127,  127,   60,  127,  127,  127,  127,  127,
      127,   10,  127,  127,  127,  127,  127,  127,    7,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,   37,  127,

      127,   20,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  110,  127,  109,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  121,  127,  122,  127,   35,  127,  127,   24,
      127,  127,  127,   41,  127,  127,   34,  127,  127,  127,
      127,   32,  127,   26,  127,  127,   36,   14,  127,  127,
       30,  127,  111,  127,  127,   90,  127,   74,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,   69,  127,
       71,  127,  127,   87,  127,  127,  127,  127,  127,  127,

      127,  127,  127,  127,  127,  127,   36,  127,  127,  127,
      127,  127,  127,  127,   16,  127,  127,  127,   42,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  117,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  123,  127,   11,
      127,   12,   33,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,   72,  127,  127,  107,

      127,   89,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  105,   96,  127,  127,   88,  118,
      119,  127,   49,  127,  127,  127,  127,   54,  127,   43,
       44,  127,   52,  127,  127,  127,    9,  127,  127,  127,
      127,   78,   81,  127,  127,   80,  127,  127,   94,  127,
       75,  127,   91,  127,   82,  127,  127,  127,  127,   83,
      127,  104,  127,  127,   98,   86,  127,  127,  127,   31,
      127,  127,  127,   48,   25,  127,  127,  127,  127,   65,
      127,  127,   79,   93,  127,  127,  127,  127,  127,  127,
      127,   84,  127,  127,  127,   50,   51,  127,  127,  127,

      127,  127,  127,  127,   99,  101,  108,   73,   92,  100,
       63,  127,  102,   85,  127,  127,  127,   56,  127,  127,
      127,  112,  113,   64,  127,   97,  127,  127,   53,  127,
       47,  103,  127,  127,  127,  127,  106,  127,  127,   58,
      127,   55,  127,   57,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   23,   23,   24,   25,   26,
       27,   28,   29,    1,   30,   31,   32,   31,   33,   34,
        7,    7,    7,    7,    7,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,    7,    7,    7,    7,
       46,   47,   48,   49,    7,    1,   50,   51,   52,   53,

       54,   55,   56,   57,   58,   59,   60,   61,   62,   63,
       64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
       74,    7,   75,   76,   77,   78,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[79] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    1,    1,    1,    1,    1,    1,    3,
        3,    3,    3,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    1,    1,    1,    1,    3,
        3,    3,    3,    3,    3,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[750] =
    {   0,
        0,    0,   29,    0,   79,   81,  944,  945,  945,  945,
      940,  915,   98,    0,  945,   80,   85,  945,  945,  914,
       85,  945,   87,  945,   92,  104,  121,  945,  945,   89,
      913,   90,  945,  141,  945,  945,  945,  871,  871,   89,
       95,  160,  102,   66,  115,  130,   59,  870,   61,   97,
      117,  135,  873,  885,  110,  945,  129,  945,  945,  135,
      867,  140,  137,  218,  142,  137,  154,  159,  158,  150,
      163,  192,  190,  199,  883,  868,  904,  903,  186,  206,
      201,  945,  945,  249,  251,  945,  926,    0,  945,  945,
      264,  268,  945,  925,  945,  945,  945,  945,  945,  945,

      945,  945,  280,  287,  302,  317,    0,  900,  945,  945,
      945,  186,  307,  323,  864,  871,  158,  857,  860,  222,
        0,  857,  853,  870,  858,  851,  854,  847,  846,    0,
      217,  851,  863,  215,  851,  858,  860,  855,  845,  228,
      838,  842,  854,  846,  836,  846,  123,  836,  847,  832,
      840,  828,  945,  945,  843,  842,  262,  286,  296,  823,
      828,  279,  822,  822,  821,  300,  152,  303,  303,  836,
      827,  220,  818,  833,  832,  180,  816,  353,  814,  824,
      313,  830,  203,  322,  813,  812,  851,  850,  318,  813,
      808,  244,  372,  387,  377,    0,  945,  945,  847,    0,

      823,  811,  817,    0,  313,  820,  815,  807,  813,  805,
      797,    0,  812,  318,  799,  793,    0,  805,  807,    0,
      790,  797,    0,  783,  785,  802,  790,  783,  809,  786,
      782,  780,  792,  791,  794,  791,  790,  789,    0,  781,
      784,    0,    0,  777,  778,    0,  780,  776,    0,  774,
      785,  780,  368,    0,  764,  764,  773,  773,  775,  761,
      757,  756,  756,  363,    0,  364,    0,  755,  766,  400,
      384,  767,  754,  755,  761,  315,  753,  747,  747,  761,
        0,  945,  945,  762,  763,  748,    0,  421,  437,  945,
      751,  776,    0,  759,  750,  737,  737,  747,    0,    0,

      750,  734,  744,   68,  771,  750,  730,  392,  764,    0,
        0,  763,  732,  724,  727,  743,  750,  722,  738,  735,
      727,  733,    0,  231,  731,  731,    0,  732,  411,  730,
      728,  720,  717,  725,  711,  727,  352,  707,  723,  707,
      710,  719,  720,  709,  711,  715,  701,  712,  712,  698,
      709,    0,    0,  708,  694,  706,  709,  708,  688,  687,
      328,  692,  685,  686,    0,  690,  684,  684,  692,  687,
      675,    0,  679,  676,  681,  682,  688,  689,    0,  682,
      677,  354,  675,  674,  679,  671,  684,  666,  665,  669,
      676,  666,  661,  663,  659,  668,  655,  669,    0,  667,

      663,    0,  663,  649,  664,  663,  649,  647,  661,  651,
      648,  644,  643,  658,  651,  657,    0,  650,    0,  637,
      640,  638,  649,  631,  632,  646,  628,  629,  634,  631,
      638,  626,  625,  299,  638,  623,  633,  621,  637,  635,
      627,  614,    0,  622,    0,  632,    0,  611,  611,    0,
      629,  614,  623,  656,  622,  622,    0,  602,  605,  621,
      620,    0,  633,    0,  612,  597,    0,    0,  627,  625,
        0,  601,  222,  600,  593,    0,  611,    0,  592,  608,
      593,  599,  589,  596,  604,  592,  583,  582,    0,  589,
        0,  599,  580,    0,  597,  578,  594,  579,  585,  586,

      583,  586,  581,  571,  587,  375,  578,  583,  580,  570,
      582,  557,  568,  575,    0,  559,  564,  559,    0,  392,
      571,  566,  565,  560,  559,  556,  565,  555,  567,  546,
      561,  553,  558,  560,  554,  541,    0,  555,  554,  557,
      556,  551,  541,  397,  546,  535,  527,  539,  530,  537,
      528,  542,  541,  526,  539,  542,  536,  534,  539,  532,
      521,  532,  522,  515,  516,  526,  520,    0,  526,    0,
      525,    0,    0,  517,  508,  410,  522,  525,  520,  519,
      501,  502,  517,  500,  518,  514,  494,  496,  495,  499,
      508,  494,  493,  508,  484,  505,    0,  493,  488,    0,

      496,    0,  485,  495,  483,  493,  482,  481,  478,  477,
      494,  475,  486,  486,    0,    0,  399,  485,    0,    0,
        0,  472,    0,  503,  488,  473,  481,  498,  483,    0,
        0,  475,    0,  464,  474,  469,    0,  479,  461,  469,
      473,    0,    0,  456,  463,    0,  454,  469,    0,  458,
        0,  470,    0,  469,    0,  449,  463,  462,  454,    0,
      445,    0,  457,  444,    0,    0,  447,  436,  444,    0,
      438,  446,  452,    0,    0,  447,  430,  433,  438,    0,
      427,  446,    0,    0,  443,  435,  434,  422,  428,  421,
      439,  471,  422,  421,  418,    0,    0,  426,  433,  454,

      416,  416,  429,  409,    0,    0,    0,    0,    0,    0,
        0,  406,    0,    0,  413,  412,  410,    0,  397,  403,
      389,    0,    0,    0,  387,    0,  402,  396,  398,  374,
        0,    0,  341,  318,  247,  240,    0,  221,  173,    0,
      167,    0,  104,    0,  945,  474,  476,  479,  108
    } ;

static yyconst flex_int16_t yy_def[750] =
    {   0,
      745,    1,    1,    3,    1,    1,  745,  745,  745,  745,
      745,  745,  746,  747,  745,  745,  748,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  747,  745,  745,  745,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  745,  745,  745,  745,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  745,  745,  747,  747,
      747,  745,  745,  746,  746,  745,  746,  747,  745,  745,
      748,  748,  745,  748,  745,  745,  745,  745,  745,  745,

      745,  745,  745,  745,  745,  745,  749,  745,  745,  745,
      745,  745,  745,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  745,  745,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  745,  747,  747,
      747,  747,  747,  747,  747,  747,  745,  745,  747,  747,
      747,  747,  745,  745,  745,  749,  745,  745,  745,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  745,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  745,  745,  747,  747,  747,  747,  745,  745,  745,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,    0,  745,  745,  745,  745
    } ;

static yyconst flex_int16_t yy_nxt[1024] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       27,   27,   27,   28,   29,   30,   31,   32,   33,   14,
       14,   14,   34,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   35,    8,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   14,   45,   14,   14,
       46,   14,   47,   48,   49,   14,   50,   51,   52,   53,
       54,   55,   14,   14,   56,   57,   58,   59,   60,   61,
       62,   63,   64,   77,   65,   77,   66,   92,   89,   67,
       68,   69,   70,   71,   93,   72,   73,   74,   96,   75,

       85,   76,   98,   86,  100,   78,   90,   78,  382,  101,
      196,   97,  134,   99,  108,  109,  111,  112,  102,  128,
      103,  137,  104,  104,  104,  104,  105,  138,  135,  129,
       79,   94,   79,   80,  382,   80,  106,  103,  117,  105,
      105,  105,  105,  105,   87,  118,  139,   81,  120,   81,
      140,  125,  119,  106,  113,  153,  113,  106,  121,  114,
      114,  114,  114,  114,  122,  126,  151,  152,  744,  130,
      141,  127,  235,  113,  106,  113,  107,  131,  114,  114,
      114,  114,  114,  132,  145,  142,  143,  155,  144,  158,
      159,  130,  236,  133,  160,  165,  118,  156,  146,  166,

      121,  147,  115,  119,  154,  129,  161,  167,  148,  169,
      174,  172,  198,  199,  218,  178,  175,  168,  202,  256,
      123,  173,  170,  137,  743,  203,  176,  135,  171,  138,
      124,  113,  177,  113,  742,  189,  114,  114,  114,  114,
      114,  139,  118,  179,  267,  140,  180,  268,  145,  119,
      145,   85,  277,   85,   86,  125,   86,  191,  181,  182,
      232,  183,  184,  190,  146,  147,   92,  192,  400,  126,
       92,  532,  148,   93,  148,  127,  206,   93,  123,  533,
      162,  741,  207,  163,  216,  217,  220,  221,  124,  227,
      164,  264,  221,  235,  400,   87,  228,   87,  193,  193,

      193,  193,  193,  103,  740,  104,  104,  104,  104,  105,
       94,  244,  194,  236,   94,  201,  739,  287,  103,  106,
      105,  105,  105,  105,  105,  195,  195,  195,  195,  195,
      113,  249,  113,  194,  106,  195,  195,  195,  195,  195,
      106,  114,  114,  114,  114,  114,  245,  246,  250,  738,
      206,  254,  219,  203,  258,  106,  207,  255,  257,  502,
      303,  304,  273,  259,  294,  503,  260,  216,  217,  394,
      261,  270,  270,  270,  270,  270,  274,  234,  202,  275,
      436,  295,  363,  364,  278,  203,  284,  304,  454,  279,
      193,  193,  193,  193,  193,  195,  195,  195,  195,  195,

      288,  413,  288,  737,  194,  289,  289,  289,  289,  289,
      303,  304,  346,  349,  454,  414,  347,  350,  270,  270,
      270,  270,  270,  348,  351,  194,  316,  386,  561,  334,
      574,  736,  335,  575,  735,  562,  387,  304,  336,  289,
      289,  289,  289,  289,  373,  354,  598,  627,  355,  734,
      356,  733,  357,  732,  358,  289,  289,  289,  289,  289,
      599,  663,  731,  730,  729,  404,  664,  728,  727,  726,
      725,  724,  405,  627,   84,   84,   84,   88,   88,   91,
       91,   91,  723,  722,  721,  720,  719,  718,  717,  716,
      715,  714,  713,  712,  711,  710,  709,  708,  707,  706,

      705,  704,  703,  702,  701,  700,  699,  698,  697,  696,
      695,  694,  693,  692,  691,  690,  689,  688,  687,  686,
      685,  684,  683,  682,  681,  680,  679,  678,  677,  676,
      675,  674,  673,  672,  671,  670,  669,  668,  667,  666,
      665,  662,  661,  660,  659,  658,  657,  656,  655,  654,
      653,  652,  651,  650,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  639,  638,  637,  636,  635,  634,
      633,  632,  631,  630,  629,  628,  626,  625,  624,  623,
      622,  621,  620,  619,  618,  617,  616,  615,  614,  613,
      612,  611,  610,  609,  608,  607,  606,  605,  604,  603,

      602,  601,  600,  597,  596,  595,  594,  593,  592,  591,
      590,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  573,  572,  571,  570,  569,
      568,  567,  566,  565,  564,  563,  560,  559,  558,  557,
      556,  555,  554,  553,  552,  551,  550,  549,  548,  547,
      546,  545,  544,  543,  542,  541,  540,  539,  538,  537,
      536,  535,  534,  531,  530,  529,  528,  527,  526,  525,
      524,  523,  522,  521,  520,  519,  518,  517,  516,  515,
      514,  513,  512,  511,  510,  509,  508,  507,  506,  505,
      504,  501,  500,  499,  498,  497,  496,  495,  494,  493,

      492,  491,  490,  489,  488,  487,  486,  485,  484,  483,
      482,  481,  480,  479,  478,  477,  476,  475,  474,  473,
      472,  471,  470,  469,  468,  467,  466,  465,  464,  463,
      462,  461,  460,  459,  458,  457,  456,  455,  453,  452,
      451,  450,  449,  448,  447,  446,  445,  444,  443,  442,
      441,  440,  439,  438,  437,  435,  434,  433,  432,  431,
      430,  429,  428,  427,  426,  425,  424,  423,  422,  421,
      420,  419,  418,  417,  416,  415,  412,  411,  410,  409,
      408,  407,  406,  403,  402,  401,  399,  398,  397,  396,
      395,  394,  393,  392,  391,  390,  389,  388,  385,  384,

      383,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  362,  361,
      360,  359,  353,  352,  345,  344,  343,  342,  341,  340,
      339,  338,  337,  333,  332,  331,  298,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,
      317,  316,  315,  314,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  302,  301,  300,  299,  298,  297,  296,
      293,  292,  291,  290,  286,  285,  283,  282,  281,  280,
      276,  272,  271,  269,  223,  266,  265,  263,  262,  253,
      252,  251,  248,  247,  243,  242,  241,  240,  239,  238,

      237,  234,  233,  232,  231,  230,  229,  226,  225,  224,
      223,  222,  219,  218,  215,  214,  213,  212,  211,  210,
      209,  208,  205,  204,  201,  200,  197,  745,  745,  188,
      187,  186,  185,  157,  150,  149,  136,  116,  115,  110,
       95,   83,   82,  745,    7,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,

      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745
    } ;

static yyconst flex_int16_t yy_chk[1024] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    5,    3,    6,    3,   17,   16,    3,
        3,    3,    3,    3,   17,    3,    3,    3,   21,    3,

       13,    3,   23,   13,   25,    5,   16,    6,  304,   25,
      749,   21,   47,   23,   30,   30,   32,   32,   25,   44,
       26,   49,   26,   26,   26,   26,   26,   49,   47,   44,
        5,   17,    6,    5,  304,    6,   26,   27,   40,   27,
       27,   27,   27,   27,   13,   40,   50,    5,   41,    6,
       50,   43,   40,   27,   34,   57,   34,   26,   41,   34,
       34,   34,   34,   34,   41,   43,   55,   55,  743,   45,
       51,   43,  147,   42,   27,   42,   26,   45,   42,   42,
       42,   42,   42,   46,   52,   51,   51,   60,   51,   62,
       63,   66,  147,   46,   63,   65,   62,   60,   52,   66,

       63,   52,   60,   62,   57,   65,   63,   67,   52,   68,
       70,   69,  112,  112,  167,   72,   70,   67,  117,  167,
       42,   69,   68,   71,  741,  117,   71,   69,   68,   71,
       42,   64,   71,   64,  739,   79,   64,   64,   64,   64,
       64,   72,   79,   73,  176,   72,   73,  176,   74,   79,
       81,   84,  183,   85,   84,   80,   85,   81,   73,   73,
      183,   73,   74,   80,   81,   74,   91,   81,  324,   80,
       92,  473,   74,   91,   81,   80,  120,   92,   64,  473,
       64,  738,  120,   64,  131,  131,  134,  134,   64,  140,
       64,  172,  172,  192,  324,   84,  140,   85,  103,  103,

      103,  103,  103,  104,  736,  104,  104,  104,  104,  104,
       91,  157,  103,  192,   92,  157,  735,  192,  105,  104,
      105,  105,  105,  105,  105,  113,  113,  113,  113,  113,
      106,  162,  106,  103,  105,  106,  106,  106,  106,  106,
      104,  114,  114,  114,  114,  114,  158,  159,  162,  734,
      159,  166,  168,  158,  169,  105,  159,  166,  168,  434,
      214,  214,  181,  169,  205,  434,  169,  166,  166,  361,
      169,  178,  178,  178,  178,  178,  181,  184,  189,  181,
      361,  205,  276,  276,  184,  189,  189,  214,  382,  184,
      193,  193,  193,  193,  193,  195,  195,  195,  195,  195,

      194,  337,  194,  733,  193,  194,  194,  194,  194,  194,
      253,  253,  264,  266,  382,  337,  264,  266,  270,  270,
      270,  270,  270,  264,  266,  193,  271,  308,  506,  253,
      520,  730,  253,  520,  729,  506,  308,  253,  253,  288,
      288,  288,  288,  288,  329,  271,  544,  576,  271,  728,
      271,  727,  271,  725,  271,  289,  289,  289,  289,  289,
      544,  617,  721,  720,  719,  329,  617,  717,  716,  715,
      712,  704,  329,  576,  746,  746,  746,  747,  747,  748,
      748,  748,  703,  702,  701,  700,  699,  698,  695,  694,
      693,  692,  691,  690,  689,  688,  687,  686,  685,  682,

      681,  679,  678,  677,  676,  673,  672,  671,  669,  668,
      667,  664,  663,  661,  659,  658,  657,  656,  654,  652,
      650,  648,  647,  645,  644,  641,  640,  639,  638,  636,
      635,  634,  632,  629,  628,  627,  626,  625,  624,  622,
      618,  614,  613,  612,  611,  610,  609,  608,  607,  606,
      605,  604,  603,  601,  599,  598,  596,  595,  594,  593,
      592,  591,  590,  589,  588,  587,  586,  585,  584,  583,
      582,  581,  580,  579,  578,  577,  575,  574,  571,  569,
      567,  566,  565,  564,  563,  562,  561,  560,  559,  558,
      557,  556,  555,  554,  553,  552,  551,  550,  549,  548,

      547,  546,  545,  543,  542,  541,  540,  539,  538,  536,
      535,  534,  533,  532,  531,  530,  529,  528,  527,  526,
      525,  524,  523,  522,  521,  518,  517,  516,  514,  513,
      512,  511,  510,  509,  508,  507,  505,  504,  503,  502,
      501,  500,  499,  498,  497,  496,  495,  493,  492,  490,
      488,  487,  486,  485,  484,  483,  482,  481,  480,  479,
      477,  475,  474,  472,  470,  469,  466,  465,  463,  461,
      460,  459,  458,  456,  455,  454,  453,  452,  451,  449,
      448,  446,  444,  442,  441,  440,  439,  438,  437,  436,
      435,  433,  432,  431,  430,  429,  428,  427,  426,  425,

      424,  423,  422,  421,  420,  418,  416,  415,  414,  413,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  403,
      401,  400,  398,  397,  396,  395,  394,  393,  392,  391,
      390,  389,  388,  387,  386,  385,  384,  383,  381,  380,
      378,  377,  376,  375,  374,  373,  371,  370,  369,  368,
      367,  366,  364,  363,  362,  360,  359,  358,  357,  356,
      355,  354,  351,  350,  349,  348,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  338,  336,  335,  334,  333,
      332,  331,  330,  328,  326,  325,  322,  321,  320,  319,
      318,  317,  316,  315,  314,  313,  312,  309,  307,  306,

      305,  303,  302,  301,  298,  297,  296,  295,  294,  292,
      291,  286,  285,  284,  280,  279,  278,  277,  275,  274,
      273,  272,  269,  268,  263,  262,  261,  260,  259,  258,
      257,  256,  255,  252,  251,  250,  248,  247,  245,  244,
      241,  240,  238,  237,  236,  235,  234,  233,  232,  231,
      230,  229,  228,  227,  226,  225,  224,  222,  221,  219,
      218,  216,  215,  213,  211,  210,  209,  208,  207,  206,
      203,  202,  201,  199,  191,  190,  188,  187,  186,  185,
      182,  180,  179,  177,  175,  174,  173,  171,  170,  165,
      164,  163,  161,  160,  156,  155,  152,  151,  150,  149,

      148,  146,  145,  144,  143,  142,  141,  139,  138,  137,
      136,  135,  133,  132,  129,  128,  127,  126,  125,  124,
      123,  122,  119,  118,  116,  115,  108,   94,   87,   78,
       77,   76,   75,   61,   54,   53,   48,   39,   38,   31,
       20,   12,   11,    7,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,

      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int swf5_flex_debug;
int swf5_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *swf5text;
#line 1 "./swf5compiler.flex"
#line 2 "./swf5compiler.flex"

#include <math.h>
#include <string.h>
#include <stdlib.h>

#include "compile.h"
#include "actiontypes.h"
#include "blocks/error.h"
#include "swf5compiler.tab.h" /* defines token types */

static int swf5debug;

static const char *lexBuffer = NULL;
static int lexBufferLen = 0;

static int  sLineNumber = 0;
static char szLine[1024];
static char msgbufs[2][1024] = { {0}, {0} }, *msgline = {0};
static int  column = 0;

static void comment();
static void comment1();
static void count();
static void countline();
static void warning(char *msg);

#define YY_INPUT(buf,result,max_size) result=lexBufferInput(buf, max_size)

/* thanks to the prolific and brilliant Raff: */
static int lexBufferInput(char *buf, int max_size)
{
  int l = lexBufferLen > max_size ? max_size : lexBufferLen;

  if (lexBufferLen <= 0)
    return YY_NULL;

  memcpy(buf, lexBuffer, l);
  lexBuffer += l;
  lexBufferLen -= l;
  return l;
}

static void unescape(char *buf)
{
  char *r, *w;

  r=buf; // read
  w=buf; // write
  while (*r)
  {
	if ( *r == '\\' )
	{
		r++;
		switch(*r)
		{
			case 'b' : *w = '\b'; break;
			case 'f' : *w = '\f'; break;
			case 'n' : *w = '\n'; break;
			case 'r' : *w = '\r'; break;
			case 't' : *w = '\t'; break;
			case 'x' :
			case 'u' : fprintf(stderr,"unsupported escape sequence\n");
				break;
			default : *w = *r; break;
		}
		w++;
		r++;
	}
	else
	{
		*w++ = *r++;
	}
  }
  *w='\0';
}

void swf5ParseInit(const char *script, int debug, int version)
{
  checkByteOrder();
  swf5restart(NULL);

  swf5debug = debug;

  lexBuffer = script;
  lexBufferLen = strlen(script);
  sLineNumber = 0;
  column = 0;
  msgline = msgbufs[0];
  swfVersion = version;
}



#line 99 "./swf5compiler.flex"
 // forward declaration needed by the following function
#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif
 static void yyunput YY_PROTO(( int c, char *buf_ptr ));

 void do_unput5(const char c) { unput(c); }
#line 1033 "lex.swf5.c"

#define INITIAL 0
#define asm 1
#define AS_V6 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int swf5wrap (void );
#else
extern int swf5wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( swf5text, swf5leng, 1, swf5out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( swf5in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( swf5in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, swf5in))==0 && ferror(swf5in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(swf5in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int swf5lex (void);

#define YY_DECL int swf5lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after swf5text and swf5leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 118 "./swf5compiler.flex"


 // Only reset start condition if in INITIAL state
 if(YY_START == INITIAL && swfVersion >= 6) {
	BEGIN(AS_V6);
 }

#line 1196 "lex.swf5.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! swf5in )
			swf5in = stdin;

		if ( ! swf5out )
			swf5out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			swf5ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				swf5_create_buffer(swf5in,YY_BUF_SIZE );
		}

		swf5_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of swf5text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 746 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 945 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 125 "./swf5compiler.flex"
{ count(); swf5lval.intVal = strtoul(swf5text, NULL, 0);
				return INTEGER;	}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 127 "./swf5compiler.flex"
{ count(); swf5lval.intVal = strtoul(swf5text, NULL, 0);
				return INTEGER; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 129 "./swf5compiler.flex"
{ count(); swf5lval.intVal = atoi(swf5text);
				return INTEGER;	}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 131 "./swf5compiler.flex"
{ count(); swf5lval.doubleVal = atof(swf5text);
				return DOUBLE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 133 "./swf5compiler.flex"
{ count(); swf5lval.intVal = atof(swf5text);
				return DOUBLE;	}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 135 "./swf5compiler.flex"
{ count();swf5lval.intVal = 1;
				return BOOLEAN;	}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 137 "./swf5compiler.flex"
{ count(); swf5lval.intVal = 0;
				return BOOLEAN;	}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 139 "./swf5compiler.flex"
{ count();	return NULLVAL;		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 140 "./swf5compiler.flex"
{ count();	return UNDEFINED;	}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 141 "./swf5compiler.flex"
{ count();	return BREAK;		}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 142 "./swf5compiler.flex"
{ count();	return CONTINUE;	}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 143 "./swf5compiler.flex"
{ count();	return FUNCTION;	}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 144 "./swf5compiler.flex"
{ count();	return ELSE;		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 145 "./swf5compiler.flex"
{ count();	return SWITCH;		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 146 "./swf5compiler.flex"
{ count();	return CASE;		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 147 "./swf5compiler.flex"
{ count();	return DEFAULT;		}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 148 "./swf5compiler.flex"
{ count();	return FOR;		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 149 "./swf5compiler.flex"
{ count();	return IN;		}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 150 "./swf5compiler.flex"
{ count();	return IF;		}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 151 "./swf5compiler.flex"
{ count();	return WHILE;		}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 152 "./swf5compiler.flex"
{ count();	return DO;		}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 153 "./swf5compiler.flex"
{ count();	return VAR;		}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 154 "./swf5compiler.flex"
{ count();	return NEW;		}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 155 "./swf5compiler.flex"
{ count();	return DELETE;		}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 156 "./swf5compiler.flex"
{ count();	return TARGETPATH;	}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 157 "./swf5compiler.flex"
{ count();	return RETURN;		}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 158 "./swf5compiler.flex"
{ count();	return WITH;		}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 159 "./swf5compiler.flex"
{ count();	BEGIN(asm); return ASM;		}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 160 "./swf5compiler.flex"
{ count();	return EVAL;		}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 161 "./swf5compiler.flex"
{ count();	return TYPEOF; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 162 "./swf5compiler.flex"
{ count();	return INSTANCEOF; }
	YY_BREAK
/* legacy functions */
case 32:
YY_RULE_SETUP
#line 165 "./swf5compiler.flex"
{ count();	return RANDOM;	}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 166 "./swf5compiler.flex"
{ count();	return GETTIMER;	}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 167 "./swf5compiler.flex"
{ count();	return LENGTH;	}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 168 "./swf5compiler.flex"
{ count();	return CONCAT;	}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 169 "./swf5compiler.flex"
{ count();	return SUBSTR;	}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 170 "./swf5compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 171 "./swf5compiler.flex"
{ count();	return INT;	}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 172 "./swf5compiler.flex"
{ count();	return ORD;	}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 173 "./swf5compiler.flex"
{ count();	return CHR;	}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 174 "./swf5compiler.flex"
{ count();	return GETURL;	}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 175 "./swf5compiler.flex"
{ count();	return GETURL1;	}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 176 "./swf5compiler.flex"
{ count();	return NEXTFRAME;	}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 177 "./swf5compiler.flex"
{ count();	return PREVFRAME;	}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 178 "./swf5compiler.flex"
{ count();	return PLAY;		}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 179 "./swf5compiler.flex"
{ count();	return STOP;		}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 180 "./swf5compiler.flex"
{ count();	return TOGGLEQUALITY;	}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 181 "./swf5compiler.flex"
{ count();	return STOPSOUNDS;	}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 182 "./swf5compiler.flex"
{ count();	return CALLFRAME;	}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 183 "./swf5compiler.flex"
{ count();	return GOTOANDPLAY;	}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 184 "./swf5compiler.flex"
{ count();	return GOTOANDSTOP;	}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 185 "./swf5compiler.flex"
{ count();	return SETTARGET;	}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 186 "./swf5compiler.flex"
{ count();	return LOADVARIABLES;	}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 187 "./swf5compiler.flex"
{ count();	return LOADMOVIE;	}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 188 "./swf5compiler.flex"
{ count();	return LOADVARIABLESNUM;	}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 189 "./swf5compiler.flex"
{ count();	return LOADMOVIENUM;	}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 190 "./swf5compiler.flex"
{ count();	return DUPLICATEMOVIECLIP; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 191 "./swf5compiler.flex"
{ count();	return REMOVEMOVIECLIP; }
	YY_BREAK
/* assembler ops */

case 59:
YY_RULE_SETUP
#line 195 "./swf5compiler.flex"
{ count();	return DUP; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 196 "./swf5compiler.flex"
{ count();	return SWAP; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 197 "./swf5compiler.flex"
{ count();	return POP; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 198 "./swf5compiler.flex"
{ count();	return PUSH; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 199 "./swf5compiler.flex"
{ count();	return SETREGISTER; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 200 "./swf5compiler.flex"
{ count();	return CALLFUNCTION; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 201 "./swf5compiler.flex"
{ count();	return CALLMETHOD; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 202 "./swf5compiler.flex"
{ count();	return AND; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 203 "./swf5compiler.flex"
{ count();	return OR; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 204 "./swf5compiler.flex"
{ count();	return XOR; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 205 "./swf5compiler.flex"
{ count();	return MODULO; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 206 "./swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 207 "./swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 208 "./swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 209 "./swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 210 "./swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 211 "./swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 212 "./swf5compiler.flex"
{ count();	return INC; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 213 "./swf5compiler.flex"
{ count();	return DEC; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 214 "./swf5compiler.flex"
{ count();	return ENUMERATE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 215 "./swf5compiler.flex"
{ count();	return INITOBJECT; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 216 "./swf5compiler.flex"
{ count();	return INITARRAY; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 217 "./swf5compiler.flex"
{ count();	return GETMEMBER; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 218 "./swf5compiler.flex"
{ count();	return SETMEMBER; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 219 "./swf5compiler.flex"
{ count();	return SHIFTLEFT; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 220 "./swf5compiler.flex"
{ count();	return SHIFTRIGHT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 221 "./swf5compiler.flex"
{ count();	return SHIFTRIGHT2; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 222 "./swf5compiler.flex"
{ count();	return VAREQUALS; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 223 "./swf5compiler.flex"
{ count();	return OLDADD; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 224 "./swf5compiler.flex"
{ count();	return SUBTRACT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 225 "./swf5compiler.flex"
{ count();	return MULTIPLY; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 226 "./swf5compiler.flex"
{ count();	return DIVIDE; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 227 "./swf5compiler.flex"
{ count();	return OLDEQUALS; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 228 "./swf5compiler.flex"
{ count();	return OLDLESSTHAN; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 229 "./swf5compiler.flex"
{ count();	return LOGICALAND; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 230 "./swf5compiler.flex"
{ count();	return LOGICALOR; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 231 "./swf5compiler.flex"
{ count();	return NOT; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 232 "./swf5compiler.flex"
{ count();	return STRINGEQ; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 233 "./swf5compiler.flex"
{ count();	return STRINGLENGTH; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 234 "./swf5compiler.flex"
{ count();	return SUBSTRING; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 235 "./swf5compiler.flex"
{ count();	return GETPROPERTY; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 236 "./swf5compiler.flex"
{ count();	return SETPROPERTY; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 237 "./swf5compiler.flex"
{ count();	return GETVARIABLE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 238 "./swf5compiler.flex"
{ count();	return SETVARIABLE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 239 "./swf5compiler.flex"
{ count();	return SETTARGETEXPRESSION; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 240 "./swf5compiler.flex"
{ count();	return STARTDRAG; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 241 "./swf5compiler.flex"
{ count();	return STOPDRAG; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 242 "./swf5compiler.flex"
{ count();	return STRINGLESSTHAN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 243 "./swf5compiler.flex"
{ count();	return MBLENGTH; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 244 "./swf5compiler.flex"
{ count();	return MBSUBSTRING; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 245 "./swf5compiler.flex"
{ count();	return MBORD; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 246 "./swf5compiler.flex"
{ count();	return MBCHR; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 247 "./swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 248 "./swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 249 "./swf5compiler.flex"
{ count();	return BRANCHIFTRUE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 250 "./swf5compiler.flex"
{ count();	return POST; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 251 "./swf5compiler.flex"
{ count();	return GET; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 252 "./swf5compiler.flex"
{ count();	return END;		}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 253 "./swf5compiler.flex"
{ count();	return EXTENDS;		}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 254 "./swf5compiler.flex"
{ count();	return TONUMBER;	}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 255 "./swf5compiler.flex"
{ count();	return TOSTRING;	}
	YY_BREAK


case 120:
YY_RULE_SETUP
#line 259 "./swf5compiler.flex"
{ count(); return TRY; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 260 "./swf5compiler.flex"
{ count(); return CATCH; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 261 "./swf5compiler.flex"
{ count(); return THROW; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 262 "./swf5compiler.flex"
{ count(); return FINALLY; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 263 "./swf5compiler.flex"
{ count(); return EEQ; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 264 "./swf5compiler.flex"
{ count(); return NEE; }
	YY_BREAK

case 126:
YY_RULE_SETUP
#line 267 "./swf5compiler.flex"
{ count(); swf5lval.str = strdup(swf5text+2);
				return REGISTER; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 271 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text);
					return IDENTIFIER;	}
	YY_BREAK
case 128:
/* rule 128 can match eol */
YY_RULE_SETUP
#line 274 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING;		}
	YY_BREAK
case 129:
/* rule 129 can match eol */
YY_RULE_SETUP
#line 279 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING; 		}
	YY_BREAK
case 130:
/* rule 130 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf5text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf5text again */
YY_RULE_SETUP
#line 284 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 131:
/* rule 131 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf5text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf5text again */
YY_RULE_SETUP
#line 288 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 292 "./swf5compiler.flex"
{ count();	comment();		}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 293 "./swf5compiler.flex"
{ count();	comment1();		}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 294 "./swf5compiler.flex"
{ count(); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 296 "./swf5compiler.flex"
{ count();	return INCR; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 297 "./swf5compiler.flex"
{ count();	return DECR; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 298 "./swf5compiler.flex"
{ count();	return LE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 299 "./swf5compiler.flex"
{ count();	return GE; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 300 "./swf5compiler.flex"
{ count();	return EQ; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 301 "./swf5compiler.flex"
{ count();	return NE; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 302 "./swf5compiler.flex"
{ count();	return LAN; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 303 "./swf5compiler.flex"
{ count();	return LOR; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 304 "./swf5compiler.flex"
{ count();	return MEQ; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 305 "./swf5compiler.flex"
{ count();	return DEQ; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 306 "./swf5compiler.flex"
{ count();	return IEQ; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 307 "./swf5compiler.flex"
{ count();	return SEQ; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 308 "./swf5compiler.flex"
{ count();	return AEQ; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 309 "./swf5compiler.flex"
{ count();	return OEQ; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 310 "./swf5compiler.flex"
{ count();	return SHL; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 311 "./swf5compiler.flex"
{ count();	return SHR; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 312 "./swf5compiler.flex"
{ count();	return SHR2; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 313 "./swf5compiler.flex"
{ count();	return SHLEQ; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 314 "./swf5compiler.flex"
{ count();	return SHREQ; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 315 "./swf5compiler.flex"
{ count();	return SHR2EQ; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 317 "./swf5compiler.flex"
{ count();	return '<'; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 318 "./swf5compiler.flex"
{ count();	return '>'; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 319 "./swf5compiler.flex"
{ count();	return ';'; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 320 "./swf5compiler.flex"
{ count();	return '='; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 321 "./swf5compiler.flex"
{ count();	return '+'; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 322 "./swf5compiler.flex"
{ count();	return '-'; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 323 "./swf5compiler.flex"
{ count();	return '&'; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 324 "./swf5compiler.flex"
{ count();	return '|'; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 325 "./swf5compiler.flex"
{ count();	return '^'; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 326 "./swf5compiler.flex"
{ count();	return '*'; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 327 "./swf5compiler.flex"
{ count();	return '/'; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 328 "./swf5compiler.flex"
{ count();	return '%'; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 329 "./swf5compiler.flex"
{ count();	return '!'; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 330 "./swf5compiler.flex"
{ count();	return '('; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 331 "./swf5compiler.flex"
{ count();	return ')'; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 332 "./swf5compiler.flex"
{ count();	return '['; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 333 "./swf5compiler.flex"
{ count();	return ']'; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 334 "./swf5compiler.flex"
{ count();	return '{'; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 335 "./swf5compiler.flex"
{ count();	BEGIN(0); return '}'; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 336 "./swf5compiler.flex"
{ count();	return ','; }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 337 "./swf5compiler.flex"
{ count();	return '.'; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 338 "./swf5compiler.flex"
{ count();	return '?'; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 339 "./swf5compiler.flex"
{ count();	return ':'; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 340 "./swf5compiler.flex"
{ count();	return '~'; }
	YY_BREAK
case 179:
/* rule 179 can match eol */
YY_RULE_SETUP
#line 342 "./swf5compiler.flex"
{ count();	strcpy(szLine, swf5text + 1);
					countline();	yyless(1);	}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 345 "./swf5compiler.flex"
SWF_error("Unrecognized character: %s\n", swf5text);
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 347 "./swf5compiler.flex"
ECHO;
	YY_BREAK
#line 2221 "lex.swf5.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(asm):
case YY_STATE_EOF(AS_V6):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed swf5in at a new source and called
			 * swf5lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = swf5in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( swf5wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * swf5text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of swf5lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					swf5realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			swf5restart(swf5in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 746 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 746 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 745);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up swf5text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					swf5restart(swf5in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( swf5wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve swf5text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void swf5restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        swf5ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            swf5_create_buffer(swf5in,YY_BUF_SIZE );
	}

	swf5_init_buffer(YY_CURRENT_BUFFER,input_file );
	swf5_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void swf5_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		swf5pop_buffer_state();
	 *		swf5push_buffer_state(new_buffer);
     */
	swf5ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	swf5_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (swf5wrap()) processing, but the only time this flag
	 * is looked at is after swf5wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void swf5_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	swf5in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE swf5_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) swf5alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) swf5alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_create_buffer()" );

	b->yy_is_our_buffer = 1;

	swf5_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with swf5_create_buffer()
 * 
 */
    void swf5_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		swf5free((void *) b->yy_ch_buf  );

	swf5free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a swf5restart() or at EOF.
 */
    static void swf5_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	swf5_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then swf5_init_buffer was _probably_
     * called from swf5restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void swf5_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		swf5_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void swf5push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	swf5ensure_buffer_stack();

	/* This block is copied from swf5_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from swf5_switch_to_buffer. */
	swf5_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void swf5pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	swf5_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		swf5_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void swf5ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf5alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf5realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE swf5_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) swf5alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	swf5_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to swf5lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       swf5_scan_bytes() instead.
 */
YY_BUFFER_STATE swf5_scan_string (yyconst char * yystr )
{
    
	return swf5_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to swf5lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE swf5_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) swf5alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = swf5_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in swf5_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf5text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		swf5text[swf5leng] = (yy_hold_char); \
		(yy_c_buf_p) = swf5text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		swf5leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int swf5get_lineno  (void)
{
        
    return swf5lineno;
}

/** Get the input stream.
 * 
 */
FILE *swf5get_in  (void)
{
        return swf5in;
}

/** Get the output stream.
 * 
 */
FILE *swf5get_out  (void)
{
        return swf5out;
}

/** Get the length of the current token.
 * 
 */
int swf5get_leng  (void)
{
        return swf5leng;
}

/** Get the current token.
 * 
 */

char *swf5get_text  (void)
{
        return swf5text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void swf5set_lineno (int  line_number )
{
    
    swf5lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see swf5_switch_to_buffer
 */
void swf5set_in (FILE *  in_str )
{
        swf5in = in_str ;
}

void swf5set_out (FILE *  out_str )
{
        swf5out = out_str ;
}

int swf5get_debug  (void)
{
        return swf5_flex_debug;
}

void swf5set_debug (int  bdebug )
{
        swf5_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from swf5lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    swf5in = stdin;
    swf5out = stdout;
#else
    swf5in = (FILE *) 0;
    swf5out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * swf5lex_init()
     */
    return 0;
}

/* swf5lex_destroy is for both reentrant and non-reentrant scanners. */
int swf5lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		swf5_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		swf5pop_buffer_state();
	}

	/* Destroy the stack itself. */
	swf5free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * swf5lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *swf5alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *swf5realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void swf5free (void * ptr )
{
	free( (char *) ptr );	/* see swf5realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 347 "./swf5compiler.flex"


static int getinput() {
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
}

int swf5wrap()
{
  return 1;
}

static void countline()
{
  if(sLineNumber != 0) {
   if(column < 1023) {
    msgline[column] = 0;
   } else {
    msgline[1023] = 0;
   }
  }

  ++sLineNumber;
  column = 0;
  msgline = msgbufs[sLineNumber & 1];
}

static int LineNumber(void)
{
   return (sLineNumber + 1);
}

static int ColumnNumber(void)
{
   return column;
}

static char *LineText(void)
{
  if(column < 1023)
    msgline[column] = 0;
  else
    msgline[1023] = 0;
  return msgline;
}

static void comment()
{
   // Handle block comments

   int c, c1;

loop:
   // We have the start of a comment so look skip everything up to the
   // end of the comment character
   while ((c = getinput()) != '*' && c != EOF)
   {
      if(column < 1023)
         msgline[column] = c;

      ++column;

      // keep the line number in synch
      if (c == '\n')
      {
         // start the output (matches the algorithim in the lexx above)
	 countline();
      }

      if (swf5debug) putchar(c);
   }

   // is this the end of comment character
   if ((c1 = getinput()) != '/' && c != EOF)
   {
      // false start as this was no end of comment
      do_unput5(c1);
      goto loop;
   }

   // write out the start of the end of comment
   if (c != EOF)
      if (swf5debug) putchar(c);

   // write out the end of the end of comment
   if (c1 != EOF) 
      if (swf5debug) putchar(c1);
}

static void comment1()
{
   // Handle comment of type 1 (ie '//')

   int c;

   // this is a line comment
   while ((c = getinput()) != '\n' && c != EOF)
   {
      if (swf5debug) putchar(c);

      if(column < 1023)
         msgline[column] = c;

      ++column;
   };

   // keep the line number in synch
   if (c == '\n')
   {
      if (swf5debug) putchar(c);

      countline();
   }
}

static void count(void)
{
   int n;

   // Count the characters to maintain the current column position
   if (swf5text[0] == '\n')
   {
      if (swf5debug) printf("\n");
   }
   else
   {
      if (swf5debug) printf("%s", swf5text);

      for(n=0; n<swf5leng; ++n, ++column)
      {
	if(column < 1023)
	  msgline[column] = swf5text[n];
      }

      //-- keep writing the stuff to standard output
      //column += swf5leng;
   }
}

static void printprog()
{
  if(sLineNumber)
    SWF_warn("\n%s", msgbufs[(sLineNumber-1)&1]);

  if(column < 1023)
    msgline[column] = 0;

  SWF_warn("\n%s", msgline);
}

static void warning(char *msg)
{
   // print a warning message
   printprog();
   SWF_warn("\n%*s", ColumnNumber(), "^");
   SWF_warn("\nLine %4.4d:  Reason: '%s' \n", LineNumber(), msg);
}

void swf5error(char *msg)
{
  // report a error
  if(strlen(swf5text))
  {
    SWF_error("\n%s\n%*s\nLine %i:  Reason: '%s'\n",
	      LineText(), ColumnNumber(), "^", LineNumber(), msg);
  }
  else
  {
    SWF_error("\nLine %d: Reason: 'Unexpected EOF found while looking for input.'\n", LineNumber());
  }
}

